@@ -44,9 +44,9 @@ CMSTtests <- function(cross,
                                  cross.type) {
     # Creates a design matrix
     le.mar <- length(chr)
-    n <- nind(cross)
+    n <- qtl::nind(cross)
     if(le.mar > 0) {
-      qtlo <- makeqtl(cross, chr, pos, what = "prob")
+      qtlo <- qtl::makeqtl(cross, chr, pos, what = "prob")
       XG <- HkDesignMatrix(qtlo, cross.type)
     }
     else {
@@ -55,12 +55,12 @@ CMSTtests <- function(cross,
     if(!is.null(intcov.nms)) {
       intcov.dat <- data.frame(cross$pheno[, intcov.nms])
       names(intcov.dat) <- intcov.nms
-      int.sub.matrix <- model.matrix( as.formula(paste("~", intcov.nms)), 
+      int.sub.matrix <- stats::model.matrix( stats::as.formula(paste("~", intcov.nms)), 
         intcov.dat)[,-1]
       covs <- data.frame(cross$pheno[, unique(c(addcov.nms, intcov.nms))])
       names(covs) <- unique(c(addcov.nms, intcov.nms))
-      form <- as.formula(paste(" ~ ", paste(names(covs), collapse="+")))
-      X <- as.matrix(model.matrix(form, data=covs)[,-1])
+      form <- stats::as.formula(paste(" ~ ", paste(names(covs), collapse="+")))
+      X <- as.matrix(stats::model.matrix(form, data=covs)[,-1])
       if(ncol(XG) > 1) {
         genobyintcov <- XG[,-1] * int.sub.matrix
         X <- cbind(XG, X, genobyintcov)
@@ -73,8 +73,8 @@ CMSTtests <- function(cross,
       if(!is.null(addcov.nms)){
         covs <- data.frame(cross$pheno[, addcov.nms])
         names(covs) <- addcov.nms
-        form <- as.formula(paste(" ~ ", paste(names(covs), collapse = "+")))
-        X <- model.matrix(form, data = covs)[,-1]
+        form <- stats::as.formula(paste(" ~ ", paste(names(covs), collapse = "+")))
+        X <- stats::model.matrix(form, data = covs)[,-1]
         if(is.null(dim(X))) {
           X <- as.matrix(X)
         }
@@ -91,7 +91,7 @@ CMSTtests <- function(cross,
     pv <- matrix(NA, 4, 4)
     for (i in 1 : 3) {
       for(j in (i + 1) : 4) {
-        pv[i, j] <- pnorm(Z[i, j], lower.tail = FALSE)
+        pv[i, j] <- stats::pnorm(Z[i, j], lower.tail = FALSE)
       }
     }
     pval.1 <- max(pv[1, 2], pv[1, 3], pv[1, 4])
@@ -118,8 +118,8 @@ CMSTtests <- function(cross,
         vec.ratio <- vec.penal[, i] - vec.penal[, j]
         counts <- sum(vec.ratio > 0)
         nn <- n - sum(vec.ratio == 0)
-        pv[i, j] <- pbinom(counts - 1, nn, 0.5, lower.tail = FALSE)
-        pv[j, i] <- pbinom(counts, nn, 0.5, lower.tail = TRUE)
+        pv[i, j] <- stats::pbinom(counts - 1, nn, 0.5, lower.tail = FALSE)
+        pv[j, i] <- stats::pbinom(counts, nn, 0.5, lower.tail = TRUE)
       }
     }
     pval.1 <- max(pv[1, 2], pv[1, 3], pv[1, 4])
@@ -131,13 +131,13 @@ CMSTtests <- function(cross,
 
   ParametricJointCMST <- function(Z, Cor.hat) {
     z <- min(Z[1, 2], Z[1, 3], Z[1, 4])
-    pval.1 <- 1 - pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[1]])
+    pval.1 <- 1 - mnormt::pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[1]])
     z <- min(- Z[1, 2], Z[2, 3], Z[2, 4])
-    pval.2 <- 1 - pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[2]])
+    pval.2 <- 1 - mnormt::pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[2]])
     z <- min(-Z[1, 3], -Z[2, 3], Z[3, 4])
-    pval.3 <- 1 - pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[3]])
+    pval.3 <- 1 - mnormt::pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[3]])
     z <- min(-Z[1, 4], -Z[2, 4], -Z[3, 4])
-    pval.4 <- 1 - pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[4]])
+    pval.4 <- 1 - mnormt::pmnorm(c(z, z, z), c(0, 0, 0), Cor.hat[[4]])
     c(pval.1, pval.2, pval.3, pval.4)
   }
 
@@ -151,7 +151,7 @@ CMSTtests <- function(cross,
     RSS <- crossprod(y - X %*% b, y - X %*% b)
     log.lik <- as.vector(- (n/2) - (n/2) * log(2 * pi) - (n/2) * log(RSS/n))
     ss <- RSS/n
-    vec.log.lik <- dnorm(y, X %*% b, sqrt(ss), log = TRUE)
+    vec.log.lik <- stats::dnorm(y, X %*% b, sqrt(ss), log = TRUE)
     list(log.lik = log.lik, vec.log.lik = vec.log.lik, d = dX, RSS = RSS)
   }
 
@@ -164,7 +164,7 @@ CMSTtests <- function(cross,
   if (!is.null(to.drop)) {
     cross <- subset(cross, ind = -to.drop)
   }
-  n <- nind(cross)
+  n <- qtl::nind(cross)
   y1 <- cross$pheno[, pheno1]
   y2 <- cross$pheno[, pheno2]
 
@@ -216,7 +216,7 @@ CMSTtests <- function(cross,
   for (i in 1 : 6) {
     vec.LR[, i] <- vec.logLik[, ip[i, 1]] - vec.logLik[, ip[i, 2]]
   }
-  S.hat <- (1 - 1/n) * cov(vec.LR)
+  S.hat <- (1 - 1/n) * stats::cov(vec.LR)
   dimnames(S.hat) <- list(dimnames(vec.LR)[[2]], dimnames(vec.LR)[[2]])
 
   if (method == "all") {
@@ -233,11 +233,11 @@ CMSTtests <- function(cross,
     Sig.hat[[4]] <- S.hat[c(3, 5, 6), c(3, 5, 6)]
     Cor.hat <- vector(mode = "list", length = 4) 
     for (i in 1 : 4) {
-      tmp <- is.positive.definite(Sig.hat[[i]])
+      tmp <- corpcor::is.positive.definite(Sig.hat[[i]])
       if (!tmp) {
-        Sig.hat[[i]] <- make.positive.definite(Sig.hat[[i]])
+        Sig.hat[[i]] <- corpcor::make.positive.definite(Sig.hat[[i]])
       }
-      Cor.hat[[i]] <- cov2cor(Sig.hat[[i]])
+      Cor.hat[[i]] <- stats::cov2cor(Sig.hat[[i]])
       attr(Sig.hat[[i]], "is.positive.definite") <- tmp
     }
     if (penalty == "both") {
@@ -350,11 +350,11 @@ CMSTtests <- function(cross,
     Sig.hat[[4]] <- S.hat[c(3, 5, 6), c(3, 5, 6)]
     Cor.hat <- vector(mode = "list", length = 4) 
     for (i in 1 : 4) {
-      tmp <- is.positive.definite(Sig.hat[[i]])
+      tmp <- corpcor::is.positive.definite(Sig.hat[[i]])
       if (!tmp) {
-        Sig.hat[[i]] <- make.positive.definite(Sig.hat[[i]])
+        Sig.hat[[i]] <- corpcor::make.positive.definite(Sig.hat[[i]])
       }
-      Cor.hat[[i]] <- cov2cor(Sig.hat[[i]])
+      Cor.hat[[i]] <- stats::cov2cor(Sig.hat[[i]])
       attr(Sig.hat[[i]], "is.positive.definite") <- tmp
     }
     if (penalty == "both") {
@@ -922,8 +922,8 @@ FitAllTests <- function(cross, pheno1, pheno2, Q.chr, Q.pos, verbose = TRUE)
   out$pvals.cit <- matrix(NA, ntests, 2, dimnames = list(nms, c("pval.1", "pval.2")))
 
   for(k in 1 : ntests) {
-    cit.mar <- find.marker(cross, Q.chr, Q.pos)
-    LL <- pull.geno(cross)[, cit.mar]
+    cit.mar <- qtl::find.marker(cross, Q.chr, Q.pos)
+    LL <- qtl::pull.geno(cross)[, cit.mar]
     GG <- cross$pheno[, pheno1]
     TT <- cross$pheno[, pheno2[k]]
     aux2 <- try(CitTests(LL, GG, TT), silent = TRUE)
@@ -953,109 +953,109 @@ CitTests <- function(LL, GG, TT)
   if(dfL == 2){
     dat_f$L1 <- ifelse(dat_f$L == 1,1,0)
     dat_f$L2 <- ifelse(dat_f$L == 2,1,0)
-    fit0 <- lm(T ~ 1, data = dat_f)
-    fit1 <- lm(T ~ L1 + L2, data = dat_f)
-    fit2 <- lm(G ~ T, data = dat_f)
-    fit3 <- lm(T ~ G, data = dat_f)
-    fit4 <- lm(G ~ T + L1 + L2, data = dat_f)
-    fit5 <- lm(T ~ G + L1 + L2, data = dat_f)
-    pvec[1] <- anova(fit0, fit1)$"Pr(>F)"[2]
-    pvec[2] <- anova(fit2, fit4)$"Pr(>F)"[2]
-    pvec[3] <- anova(fit1, fit5)$"Pr(>F)"[2]
-    f_ <- anova(fit3, fit5)$F[2]
-    fit1G <- lm(G ~ L1 + L2, data = dat_f)
+    fit0 <- stats::lm(T ~ 1, data = dat_f)
+    fit1 <- stats::lm(T ~ L1 + L2, data = dat_f)
+    fit2 <- stats::lm(G ~ T, data = dat_f)
+    fit3 <- stats::lm(T ~ G, data = dat_f)
+    fit4 <- stats::lm(G ~ T + L1 + L2, data = dat_f)
+    fit5 <- stats::lm(T ~ G + L1 + L2, data = dat_f)
+    pvec[1] <- stats::anova(fit0, fit1)$"Pr(>F)"[2]
+    pvec[2] <- stats::anova(fit2, fit4)$"Pr(>F)"[2]
+    pvec[3] <- stats::anova(fit1, fit5)$"Pr(>F)"[2]
+    f_ <- stats::anova(fit3, fit5)$F[2]
+    fit1G <- stats::lm(G ~ L1 + L2, data = dat_f)
     alg <- summary(fit1G)$coefficients["(Intercept)", 1]
     blg1 <- summary(fit1G)$coefficients["L1", 1]
     blg2 <- summary(fit1G)$coefficients["L2", 1]
     alt <- summary(fit1)$coefficients["(Intercept)", 1]
     blt1 <- summary(fit1)$coefficients["L1", 1]
     blt2 <- summary(fit1)$coefficients["L2", 1]
-    dat_f$eG <- resid(fit1G)
-    dat_f$eT <- resid(fit1)
+    dat_f$eG <- stats::resid(fit1G)
+    dat_f$eT <- stats::resid(fit1)
     ss <- dim(dat_f)[1]
     fvecr <- rep(NA, no.bootstrap)
     fvecr_r <- rep(NA, no.bootstrap)
     for (i in 1 : no.bootstrap) {
-      nni <- trunc(1 + ss*runif(ss, 0, 1)) ;
+      nni <- trunc(1 + ss * stats::runif(ss, 0, 1)) ;
       dat_f$G_ <- alg + blg1 * dat_f$L1 + blg2 * dat_f$L2 + dat_f$eG[nni]
-      fit_0 <- lm(T ~ G_, data = dat_f)
-      fit_1 <- lm(T ~ G_ + L1 + L2, data = dat_f)
-      fvecr[i] <- anova(fit_0, fit_1)$F[2]
+      fit_0 <- stats::lm(T ~ G_, data = dat_f)
+      fit_1 <- stats::lm(T ~ G_ + L1 + L2, data = dat_f)
+      fvecr[i] <- stats::anova(fit_0, fit_1)$F[2]
       dat_f$T_ <- alt + blt1 * dat_f$L1 + blt2 * dat_f$L2 + dat_f$eT[nni]
-      fit_0 <- lm(G ~ T_, data = dat_f)
-      fit_1 <- lm(G ~ T_ + L1 + L2, data = dat_f)
-      fvecr_r[i] <- anova(fit_0, fit_1)$F[2]
+      fit_0 <- stats::lm(G ~ T_, data = dat_f)
+      fit_1 <- stats::lm(G ~ T_ + L1 + L2, data = dat_f)
+      fvecr_r[i] <- stats::anova(fit_0, fit_1)$F[2]
     }
   }#End dfL == 2
 
   if(dfL == 1){
     dat_f$L1 <- ifelse(dat_f$L == 1, 1, 0)
-    fit0 <- lm(T ~ 1, data = dat_f)
-    fit1 <- lm(T ~ L1, data = dat_f)
-    fit2 <- lm(G ~ T, data = dat_f)
-    fit3 <- lm(T ~ G, data = dat_f)
-    fit4 <- lm(G ~ T + L1, data = dat_f)
-    fit5 <- lm(T ~ G + L1, data = dat_f)
-    pvec[1] <- anova(fit0, fit1)$"Pr(>F)"[2]
-    pvec[2] <- anova(fit2, fit4)$"Pr(>F)"[2]
-    pvec[3] <- anova(fit1, fit5)$"Pr(>F)"[2]
-    f_ <- anova(fit3, fit5)$F[2]
-    fit1G <- lm(G ~ L1, data = dat_f)
+    fit0 <- stats::lm(T ~ 1, data = dat_f)
+    fit1 <- stats::lm(T ~ L1, data = dat_f)
+    fit2 <- stats::lm(G ~ T, data = dat_f)
+    fit3 <- stats::lm(T ~ G, data = dat_f)
+    fit4 <- stats::lm(G ~ T + L1, data = dat_f)
+    fit5 <- stats::lm(T ~ G + L1, data = dat_f)
+    pvec[1] <- stats::anova(fit0, fit1)$"Pr(>F)"[2]
+    pvec[2] <- stats::anova(fit2, fit4)$"Pr(>F)"[2]
+    pvec[3] <- stats::anova(fit1, fit5)$"Pr(>F)"[2]
+    f_ <- stats::anova(fit3, fit5)$F[2]
+    fit1G <- stats::lm(G ~ L1, data = dat_f)
     alt <- summary(fit1)$coefficients["(Intercept)", 1]
     blt1 <- summary(fit1)$coefficients["L1", 1]
     alg <- summary(fit1G)$coefficients["(Intercept)", 1]
     blg1 <- summary(fit1G)$coefficients["L1", 1]
-    dat_f$eG <- resid(fit1G)
-    dat_f$eT <- resid(fit1)
+    dat_f$eG <- stats::resid(fit1G)
+    dat_f$eT <- stats::resid(fit1)
     ss <- dim(dat_f)[1]
     fvecr <- rep(NA, no.bootstrap)
     fvecr_r <- rep(NA, no.bootstrap)
     for (i in 1 : no.bootstrap) {
-      nni <- trunc(1 + ss*runif(ss, 0, 1)) 
+      nni <- trunc(1 + ss * stats::runif(ss, 0, 1)) 
       dat_f$G_ <- alg + blg1 * dat_f$L1 + dat_f$eG[nni]
-      fit_0 <- lm(T ~ G_, data = dat_f)
-      fit_1 <- lm(T ~ G_ + L1, data = dat_f)
-      fvecr[i] <- anova(fit_0, fit_1)$F[2]
+      fit_0 <- stats::lm(T ~ G_, data = dat_f)
+      fit_1 <- stats::lm(T ~ G_ + L1, data = dat_f)
+      fvecr[i] <- stats::anova(fit_0, fit_1)$F[2]
       dat_f$T_ <- alt + blt1 * dat_f$L1 + dat_f$eT[nni]
-      fit_0 <- lm(G ~ T_, data = dat_f)
-      fit_1 <- lm(G ~ T_ + L1, data = dat_f)
-      fvecr_r[i] <- anova(fit_0, fit_1)$F[2]
+      fit_0 <- stats::lm(G ~ T_, data = dat_f)
+      fit_1 <- stats::lm(G ~ T_ + L1, data = dat_f)
+      fvecr_r[i] <- stats::anova(fit_0, fit_1)$F[2]
     }
   } #End dfL == 1
 
   #####F Method
   fvecr <- fvecr[!is.na(fvecr)]
-  df1 <- anova(fit3, fit5)$Df[2]
-  df2 <- anova(fit3, fit5)$Res.Df[2]
+  df1 <- stats::anova(fit3, fit5)$Df[2]
+  df2 <- stats::anova(fit3, fit5)$Res.Df[2]
   fncp <- mean(fvecr, na.rm = TRUE) * (df1/df2) * (df2 - df1) - df1
   if(fncp < 0) fncp <- 0
   ######### Transform F to normal
-  npvals <- pf(fvecr, df1, df2, ncp = fncp, lower.tail = TRUE)
-  nfvecr <- qnorm(npvals)
-  npf <- pf(f_, df1, df2, ncp = fncp, lower.tail = TRUE) #Transform observed F
-  zf <- qnorm(npf)
-  pvec[4] <- pnorm(zf, mean = 0, sd = sd(nfvecr))
+  npvals <- stats::pf(fvecr, df1, df2, ncp = fncp, lower.tail = TRUE)
+  nfvecr <- stats::qnorm(npvals)
+  npf <- stats::pf(f_, df1, df2, ncp = fncp, lower.tail = TRUE) #Transform observed F
+  zf <- stats::qnorm(npf)
+  pvec[4] <- stats::pnorm(zf, mean = 0, sd = stats::sd(nfvecr))
   pvalc <- max(pvec)  ###Causal p-value
 
   #### Reactive p-value
-  fit0G <- lm(G ~ 1, data = dat_f)
+  fit0G <- stats::lm(G ~ 1, data = dat_f)
   pvec1 <- rep(NA, 4)
-  pvec1[1] <- anova(fit0G, fit1G)$"Pr(>F)"[2]
-  pvec1[2] <- anova(fit3, fit5)$"Pr(>F)"[2]
-  pvec1[3] <- anova(fit1G, fit4)$"Pr(>F)"[2]
-  f_ <- anova(fit2, fit4)$F[2]
+  pvec1[1] <- stats::anova(fit0G, fit1G)$"Pr(>F)"[2]
+  pvec1[2] <- stats::anova(fit3, fit5)$"Pr(>F)"[2]
+  pvec1[3] <- stats::anova(fit1G, fit4)$"Pr(>F)"[2]
+  f_ <- stats::anova(fit2, fit4)$F[2]
   #####F Method
   fvecr_r <- fvecr_r[!is.na(fvecr_r)]
-  df1 <- anova(fit3, fit5)$Df[2]
-  df2 <- anova(fit3, fit5)$Res.Df[2]
+  df1 <- stats::anova(fit3, fit5)$Df[2]
+  df2 <- stats::anova(fit3, fit5)$Res.Df[2]
   fncp <- mean(fvecr_r, na.rm = TRUE) * (df1/df2) * (df2 - df1) - df1
   if(fncp < 0) fncp <- 0
   ######### Transform F to normal
-  npvals <- pf(fvecr_r, df1, df2, ncp = fncp, lower.tail = TRUE)
-  nfvecr <- qnorm(npvals)
-  npf <- pf(f_, df1, df2, ncp = fncp, lower.tail = TRUE) #Transform observed F
-  zf <- qnorm(npf)
-  pvec1[4] <- pnorm(zf, mean = 0, sd = sd(nfvecr))
+  npvals <- stats::pf(fvecr_r, df1, df2, ncp = fncp, lower.tail = TRUE)
+  nfvecr <- stats::qnorm(npvals)
+  npf <- stats::pf(f_, df1, df2, ncp = fncp, lower.tail = TRUE) #Transform observed F
+  zf <- stats::qnorm(npf)
+  pvec1[4] <- stats::pnorm(zf, mean = 0, sd = stats::sd(nfvecr))
   pvalr <- max(pvec1)  ###Reactive p-value
   ###
   c(pvalc, pvalr)
@@ -1077,8 +1077,8 @@ GetCommonQtls <- function(cross,
   CreateCovMatrix <- function(cross, cov.names) {
     # get covariates data
     if (!is.null(cov.names)) {
-      myformula <- formula(paste("~", paste(cov.names, collapse = "+")))
-      out <- model.matrix(myformula, cross$pheno)[, -1]
+      myformula <- stats::formula(paste("~", paste(cov.names, collapse = "+")))
+      out <- stats::model.matrix(myformula, cross$pheno)[, -1]
     }
     else {
       out <- NULL
@@ -1109,7 +1109,7 @@ GetCommonQtls <- function(cross,
         aux6 <- which.max(ssJ[aux5, 3])
         Q.chr <- as.numeric(ssJ[aux5[aux6], 1])
         Q.pos <- ssJ[aux5[aux6], 2]
-        Q <- find.pseudomarker(cross, Q.chr, Q.pos, "prob")
+        Q <- qtl::find.pseudomarker(cross, Q.chr, Q.pos, "prob")
         Q <- data.frame(Q, Q.chr, Q.pos, stringsAsFactors = FALSE)
       }
     }
@@ -1121,20 +1121,20 @@ GetCommonQtls <- function(cross,
   if (!is.null(to.drop)) {
     cross <- subset(cross, ind = -to.drop)
   }
-  n <- nind(cross)
+  n <- qtl::nind(cross)
   y1 <- cross$pheno[, pheno1]
   y2 <- cross$pheno[, pheno2]
   addcov1.M <- CreateCovMatrix(cross, cov.names = addcov1)
   addcov2.M <- CreateCovMatrix(cross, cov.names = addcov2)
   intcov1.M <- CreateCovMatrix(cross, cov.names = intcov1)
   intcov2.M <- CreateCovMatrix(cross, cov.names = intcov2)
-  scan1 <- scanone(cross, pheno.col = find.pheno(cross, pheno1), 
+  scan1 <- qtl::scanone(cross, pheno.col = qtl::find.pheno(cross, pheno1), 
                    method = "hk", intcovar = intcov1.M,
                    addcovar = cbind(addcov1.M, intcov1.M))
-  scan2 <- scanone(cross, pheno.col = find.pheno(cross, pheno2), 
+  scan2 <- qtl::scanone(cross, pheno.col = qtl::find.pheno(cross, pheno2), 
                    method = "hk", intcovar = intcov2.M, 
                    addcovar = cbind(addcov2.M, intcov2.M))
-  scan2g1 <- scanone(cross, pheno.col = find.pheno(cross, pheno2), 
+  scan2g1 <- qtl::scanone(cross, pheno.col = qtl::find.pheno(cross, pheno2), 
                      method = "hk", intcovar = intcov2.M,
                      addcovar = cbind(addcov2.M, intcov2.M, y1))
   scanJ <- scan1
@@ -1461,7 +1461,7 @@ p.adjust.np <- function(tests, method = "BH")
 {
   for(test.name in paste("pvals.np", c("AIC","BIC"), sep = "."))
     for (i in seq(ncol(tests[[test.name]])))
-      tests[[test.name]][, i] <- p.adjust(tests[[test.name]][, i], method = method)
+      tests[[test.name]][, i] <- stats::p.adjust(tests[[test.name]][, i], method = method)
 
   tests
 
@@ -1653,7 +1653,7 @@ CreateTraitsLodInt <- function(scan, annot, traits, lod.thr, drop = 1.5)
       if(peak >= lod.thr){
         trait.index <- match(traits[i], nms)
         sscan <- scan[, c(1, 2, trait.index + 2)]
-        lod.interval <- lodint(sscan, chr = trait.chr, drop)
+        lod.interval <- qtl::lodint(sscan, chr = trait.chr, drop)
         lb <- lod.interval[1, 2]
         ub <- lod.interval[3, 2]
         out[i, 4] <- lb
