@@ -49,15 +49,15 @@ mySimulations <- function(
   if(model=="A"){
     k <- 1
     while(k <= nSim){
-      mu <- runif(1,mu.range[1],mu.range[2])
-      beta21 <- runif(1,beta21.range[1],beta21.range[2])
-      add.eff1 <- runif(1,add.eff1.range[1],add.eff1.range[2])
-      dom.eff1 <- runif(1,dom.eff1.range[1],dom.eff1.range[2])
-      sig2.1 <- runif(1,sig2.1.range[1],sig2.1.range[2])
-      sig2.2 <- runif(1,sig2.2.range[1],sig2.2.range[2])
-      Cross <- sim.cross.1(n.ind, mu, beta21, add.eff1, dom.eff1, sig2.1, 
+      mu <- stats::runif(1,mu.range[1],mu.range[2])
+      beta21 <- stats::runif(1,beta21.range[1],beta21.range[2])
+      add.eff1 <- stats::runif(1,add.eff1.range[1],add.eff1.range[2])
+      dom.eff1 <- stats::runif(1,dom.eff1.range[1],dom.eff1.range[2])
+      sig2.1 <- stats::runif(1,sig2.1.range[1],sig2.1.range[2])
+      sig2.2 <- stats::runif(1,sig2.2.range[1],sig2.2.range[2])
+      Cross <- qtl::sim.cross.1(n.ind, mu, beta21, add.eff1, dom.eff1, sig2.1, 
         sig2.2, eq.spacing, cross.type, normalize)
-      Cross <- calc.genoprob(Cross, step=2)
+      Cross <- qtl::calc.genoprob(Cross, step=2)
       cq <- get.common.qtls(Cross, "y1", "y2", thr, peak.dist)
       if(!is.na(cq[1])){
         print(k)
@@ -77,8 +77,8 @@ mySimulations <- function(
           pval.par.cmst.iu.AIC[k,] <- aux$pvals.par.cmst.iu.AIC
           pval.non.par.cmst.iu.AIC[k,] <- aux$pvals.non.par.cmst.iu.AIC
         }
-        cit.mar <- find.marker(Cross,cq[1,2],cq[1,3])
-        LL <- pull.geno(Cross)[,cit.mar]
+        cit.mar <- qtl::find.marker(Cross,cq[1,2],cq[1,3])
+        LL <- qtl::pull.geno(Cross)[,cit.mar]
         GG <- Cross$pheno[,1]
         TT <- Cross$pheno[,2]
         aux2 <- try(citTests(LL, GG, TT),silent=TRUE)
@@ -91,18 +91,18 @@ mySimulations <- function(
   if(model=="B"){
     k <- 1
     while(k <= nSim){
-      mu <- runif(1,mu.range[1],mu.range[2])
-      beta21 <- runif(1,beta21.range[1],beta21.range[2])
-      beta1h <- runif(1,beta1h.range[1],beta1h.range[2])
-      beta2h <- runif(1,beta2h.range[1],beta2h.range[2])
-      add.eff1 <- runif(1,add.eff1.range[1],add.eff1.range[2])
-      dom.eff1 <- runif(1,dom.eff1.range[1],dom.eff1.range[2])
-      sig2.1 <- runif(1,sig2.1.range[1],sig2.1.range[2])
-      sig2.2 <- runif(1,sig2.2.range[1],sig2.2.range[2])
-      sig2.h <- runif(1,sig2.h.range[1],sig2.h.range[2])
-      Cross <- sim.cross.2(n.ind, mu, beta21, beta1h, beta2h, add.eff1, 
+      mu <- stats::runif(1,mu.range[1],mu.range[2])
+      beta21 <- stats::runif(1,beta21.range[1],beta21.range[2])
+      beta1h <- stats::runif(1,beta1h.range[1],beta1h.range[2])
+      beta2h <- stats::runif(1,beta2h.range[1],beta2h.range[2])
+      add.eff1 <- stats::runif(1,add.eff1.range[1],add.eff1.range[2])
+      dom.eff1 <- stats::runif(1,dom.eff1.range[1],dom.eff1.range[2])
+      sig2.1 <- stats::runif(1,sig2.1.range[1],sig2.1.range[2])
+      sig2.2 <- stats::runif(1,sig2.2.range[1],sig2.2.range[2])
+      sig2.h <- stats::runif(1,sig2.h.range[1],sig2.h.range[2])
+      Cross <- qtl::sim.cross.2(n.ind, mu, beta21, beta1h, beta2h, add.eff1, 
         dom.eff1, sig2.1, sig2.2, sig2.h, eq.spacing, cross.type, normalize)
-      Cross <- calc.genoprob(Cross, step=2)
+      Cross <- qtl::calc.genoprob(Cross, step=2)
       cq <- get.common.qtls(Cross, "y1", "y2", thr, peak.dist)
       if(!is.na(cq[1])){
         print(k)
@@ -122,8 +122,8 @@ mySimulations <- function(
           pval.par.cmst.iu.AIC[k,] <- aux$pvals.par.cmst.iu.AIC
           pval.non.par.cmst.iu.AIC[k,] <- aux$pvals.non.par.cmst.iu.AIC
         }
-        cit.mar <- find.marker(Cross,cq[1,2],cq[1,3])
-        LL <- pull.geno(Cross)[,cit.mar]
+        cit.mar <- qtl::find.marker(Cross,cq[1,2],cq[1,3])
+        LL <- qtl::pull.geno(Cross)[,cit.mar]
         GG <- Cross$pheno[,1]
         TT <- Cross$pheno[,2]
         aux2 <- try(citTests(LL, GG, TT),silent=TRUE)
@@ -136,17 +136,17 @@ mySimulations <- function(
   if(model=="C"){
     k <- 1
     while(k <= nSim){
-      mu <- runif(1,mu.range[1],mu.range[2])
-      beta21 <- runif(1,beta21.range[1],beta21.range[2])
-      add.eff1 <- runif(1,add.eff1.range[1],add.eff1.range[2])
-      dom.eff1 <- runif(1,dom.eff1.range[1],dom.eff1.range[2])
-      add.eff2 <- runif(1,add.eff2.range[1],add.eff2.range[2])
-      dom.eff2 <- runif(1,dom.eff2.range[1],dom.eff2.range[2])
-      sig2.1 <- runif(1,sig2.1.range[1],sig2.1.range[2])
-      sig2.2 <- runif(1,sig2.2.range[1],sig2.2.range[2])
-      Cross <- sim.cross.3(n.ind, mu, beta21, add.eff1, dom.eff1, add.eff2, 
+      mu <- stats::runif(1,mu.range[1],mu.range[2])
+      beta21 <- stats::runif(1,beta21.range[1],beta21.range[2])
+      add.eff1 <- stats::runif(1,add.eff1.range[1],add.eff1.range[2])
+      dom.eff1 <- stats::runif(1,dom.eff1.range[1],dom.eff1.range[2])
+      add.eff2 <- stats::runif(1,add.eff2.range[1],add.eff2.range[2])
+      dom.eff2 <- stats::runif(1,dom.eff2.range[1],dom.eff2.range[2])
+      sig2.1 <- stats::runif(1,sig2.1.range[1],sig2.1.range[2])
+      sig2.2 <- stats::runif(1,sig2.2.range[1],sig2.2.range[2])
+      Cross <- qtl::sim.cross.3(n.ind, mu, beta21, add.eff1, dom.eff1, add.eff2, 
         dom.eff2, sig2.1, sig2.2, eq.spacing, cross.type, normalize)
-      Cross <- calc.genoprob(Cross, step=2)
+      Cross <- qtl::calc.genoprob(Cross, step=2)
       cq <- get.common.qtls(Cross, "y1", "y2", thr, peak.dist)
       if(!is.na(cq[1])){
         print(k)
@@ -166,8 +166,8 @@ mySimulations <- function(
           pval.par.cmst.iu.AIC[k,] <- aux$pvals.par.cmst.iu.AIC
           pval.non.par.cmst.iu.AIC[k,] <- aux$pvals.non.par.cmst.iu.AIC
         }
-        cit.mar <- find.marker(Cross,cq[1,2],cq[1,3])
-        LL <- pull.geno(Cross)[,cit.mar]
+        cit.mar <- qtl::find.marker(Cross,cq[1,2],cq[1,3])
+        LL <- qtl::pull.geno(Cross)[,cit.mar]
         GG <- Cross$pheno[,1]
         TT <- Cross$pheno[,2]
         aux2 <- try(citTests(LL, GG, TT),silent=TRUE)
@@ -180,16 +180,16 @@ mySimulations <- function(
   if(model=="D"){
     k <- 1
     while(k <= nSim){
-      mu <- runif(1,mu.range[1],mu.range[2])
-      add.eff1 <- runif(1,add.eff1.range[1],add.eff1.range[2])
-      dom.eff1 <- runif(1,dom.eff1.range[1],dom.eff1.range[2])
-      add.eff2 <- runif(1,add.eff2.range[1],add.eff2.range[2])
-      dom.eff2 <- runif(1,dom.eff2.range[1],dom.eff2.range[2])
-      sig2.1 <- runif(1,sig2.1.range[1],sig2.1.range[2])
-      sig2.2 <- runif(1,sig2.2.range[1],sig2.2.range[2])
-      Cross <- sim.cross.4(n.ind, mu, add.eff1, dom.eff1, add.eff2, 
+      mu <- stats::runif(1,mu.range[1],mu.range[2])
+      add.eff1 <- stats::runif(1,add.eff1.range[1],add.eff1.range[2])
+      dom.eff1 <- stats::runif(1,dom.eff1.range[1],dom.eff1.range[2])
+      add.eff2 <- stats::runif(1,add.eff2.range[1],add.eff2.range[2])
+      dom.eff2 <- stats::runif(1,dom.eff2.range[1],dom.eff2.range[2])
+      sig2.1 <- stats::runif(1,sig2.1.range[1],sig2.1.range[2])
+      sig2.2 <- stats::runif(1,sig2.2.range[1],sig2.2.range[2])
+      Cross <- qtl::sim.cross.4(n.ind, mu, add.eff1, dom.eff1, add.eff2, 
         dom.eff2, sig2.1, sig2.2, eq.spacing, cross.type, normalize)
-      Cross <- calc.genoprob(Cross, step=2)
+      Cross <- qtl::calc.genoprob(Cross, step=2)
       cq <- get.common.qtls(Cross, "y1", "y2", thr, peak.dist)
       if(!is.na(cq[1])){
         print(k)
@@ -209,8 +209,8 @@ mySimulations <- function(
           pval.par.cmst.iu.AIC[k,] <- aux$pvals.par.cmst.iu.AIC
           pval.non.par.cmst.iu.AIC[k,] <- aux$pvals.non.par.cmst.iu.AIC
         }
-        cit.mar <- find.marker(Cross,cq[1,2],cq[1,3])
-        LL <- pull.geno(Cross)[,cit.mar]
+        cit.mar <- qtl::find.marker(Cross,cq[1,2],cq[1,3])
+        LL <- qtl::pull.geno(Cross)[,cit.mar]
         GG <- Cross$pheno[,1]
         TT <- Cross$pheno[,2]
         aux2 <- try(citTests(LL, GG, TT),silent=TRUE)
@@ -223,20 +223,20 @@ mySimulations <- function(
   if(model=="E"){
     k <- 1
     while(k <= nSim){
-      mu <- runif(1,mu.range[1],mu.range[2])
-      add.eff1 <- runif(1,add.eff1.range[1],add.eff1.range[2])
-      dom.eff1 <- runif(1,dom.eff1.range[1],dom.eff1.range[2])
-      add.eff2 <- runif(1,add.eff2.range[1],add.eff2.range[2])
-      dom.eff2 <- runif(1,dom.eff2.range[1],dom.eff2.range[2])
-      beta1h <- runif(1,beta1h.range[1],beta1h.range[2])
-      beta2h <- runif(1,beta2h.range[1],beta2h.range[2])
-      sig2.1 <- runif(1,sig2.1.range[1],sig2.1.range[2])
-      sig2.2 <- runif(1,sig2.2.range[1],sig2.2.range[2])
-      sig2.h <- runif(1,sig2.h.range[1],sig2.h.range[2])
-      Cross <- sim.cross.5(n.ind, mu, add.eff1, dom.eff1, add.eff2, dom.eff2, 
+      mu <- stats::runif(1,mu.range[1],mu.range[2])
+      add.eff1 <- stats::runif(1,add.eff1.range[1],add.eff1.range[2])
+      dom.eff1 <- stats::runif(1,dom.eff1.range[1],dom.eff1.range[2])
+      add.eff2 <- stats::runif(1,add.eff2.range[1],add.eff2.range[2])
+      dom.eff2 <- stats::runif(1,dom.eff2.range[1],dom.eff2.range[2])
+      beta1h <- stats::runif(1,beta1h.range[1],beta1h.range[2])
+      beta2h <- stats::runif(1,beta2h.range[1],beta2h.range[2])
+      sig2.1 <- stats::runif(1,sig2.1.range[1],sig2.1.range[2])
+      sig2.2 <- stats::runif(1,sig2.2.range[1],sig2.2.range[2])
+      sig2.h <- stats::runif(1,sig2.h.range[1],sig2.h.range[2])
+      Cross <- qtl::sim.cross.5(n.ind, mu, add.eff1, dom.eff1, add.eff2, dom.eff2, 
         beta1h, beta2h, sig2.1, sig2.2, sig2.h, eq.spacing, cross.type,
         normalize)
-      Cross <- calc.genoprob(Cross, step=2)
+      Cross <- qtl::calc.genoprob(Cross, step=2)
       cq <- get.common.qtls(Cross, "y1", "y2", thr, peak.dist)
       if(!is.na(cq[1])){
         print(k)
@@ -256,8 +256,8 @@ mySimulations <- function(
           pval.par.cmst.iu.AIC[k,] <- aux$pvals.par.cmst.iu.AIC
           pval.non.par.cmst.iu.AIC[k,] <- aux$pvals.non.par.cmst.iu.AIC
         }
-        cit.mar <- find.marker(Cross,cq[1,2],cq[1,3])
-        LL <- pull.geno(Cross)[,cit.mar]
+        cit.mar <- qtl::find.marker(Cross,cq[1,2],cq[1,3])
+        LL <- qtl::pull.geno(Cross)[,cit.mar]
         GG <- Cross$pheno[,1]
         TT <- Cross$pheno[,2]
         aux2 <- try(citTests(LL, GG, TT),silent=TRUE)
@@ -287,22 +287,22 @@ SimCrossCausal <- function(n.ind, len, n.mar, beta, add.eff, dom.eff,
                            cross.type = c("bc", "f2"), normalize = FALSE) {
   n.traits <- length(beta)
   beta <- matrix(rep(beta, each = n.ind), n.ind, n.traits)
-  Map <- sim.map(len, n.mar, eq.spacing = eq.spacing, include.x = FALSE)
-  Cross <- sim.cross(map = Map, n.ind = n.ind, type = cross.type)
-  mygeno <- pull.geno(Cross)
+  Map <- qtl::sim.map(len, n.mar, eq.spacing = eq.spacing, include.x = FALSE)
+  Cross <- qtl::sim.cross(map = Map, n.ind = n.ind, type = cross.type)
+  mygeno <- qtl::pull.geno(Cross)
   q <- mygeno[, "D1M51"]
   
   cross.type <- match.arg(cross.type)
   if (cross.type == "bc") {
     add.q <- q - 1.5
-    y1 <- add.q * add.eff + rnorm(n.ind, 0, sqrt(sig2.1))
+    y1 <- add.q * add.eff + stats::rnorm(n.ind, 0, sqrt(sig2.1))
   }
   if (cross.type == "f2") {
     add.q <- q - 2
     dom.q <- (1 + add.q) * (1 - add.q) - 0.5
-    y1 <- add.q * add.eff + dom.q * dom.eff + rnorm(n.ind, 0, sqrt(sig2.1))
+    y1 <- add.q * add.eff + dom.q * dom.eff + stats::rnorm(n.ind, 0, sqrt(sig2.1))
   }
-  y <- beta * y1 + matrix(rnorm(n.ind * n.traits, 0, sqrt(sig2.2)), n.ind, n.traits)
+  y <- beta * y1 + matrix(stats::rnorm(n.ind * n.traits, 0, sqrt(sig2.2)), n.ind, n.traits)
   y <- data.frame(y1, y)
   names(y) <- paste("y", 1 : (n.traits + 1), sep = "")
   if (normalize) {
@@ -315,22 +315,22 @@ SimCrossCausal <- function(n.ind, len, n.mar, beta, add.eff, dom.eff,
 SimCross1 <- function(n.ind, mu, beta21, add.eff1, dom.eff1, 
                       sig2.1 = 1, sig2.2 = 1, eq.spacing = FALSE, 
                       cross.type = "f2", normalize = FALSE) {
-  Map <- sim.map(len = rep(100,3), n.mar = 101, eq.spacing = eq.spacing, 
+  Map <- qtl::sim.map(len = rep(100,3), n.mar = 101, eq.spacing = eq.spacing, 
                  include.x = FALSE)
-  Cross <- sim.cross(map = Map, n.ind = n.ind, type = cross.type)
-  mygeno <- pull.geno(Cross)
+  Cross <- qtl::sim.cross(map = Map, n.ind = n.ind, type = cross.type)
+  mygeno <- qtl::pull.geno(Cross)
   q <- mygeno[, "D1M51"]
   if (cross.type == "bc") {
     add.q <- q - 1.5
-    y1 <- mu + add.q * add.eff1 + rnorm(n.ind, 0, sqrt(sig2.1))
+    y1 <- mu + add.q * add.eff1 + stats::rnorm(n.ind, 0, sqrt(sig2.1))
   }
   if (cross.type == "f2") {
     add.q <- q - 2
     dom.q <- (1 + add.q) * (1 - add.q) - 0.5
     y1 <- mu + add.q * add.eff1 + dom.q * dom.eff1 + 
-          rnorm(n.ind, 0, sqrt(sig2.1))
+          stats::rnorm(n.ind, 0, sqrt(sig2.1))
   }
-  y2 <- mu + beta21 * y1 + rnorm(n.ind, 0, sqrt(sig2.2))
+  y2 <- mu + beta21 * y1 + stats::rnorm(n.ind, 0, sqrt(sig2.2))
   if (normalize) {
     y1 <- normal.trans(y1)
     y2 <- normal.trans(y2)
@@ -343,23 +343,23 @@ SimCross1 <- function(n.ind, mu, beta21, add.eff1, dom.eff1,
 SimCross2 <- function(n.ind, mu, beta21, beta1h, beta2h, add.eff1, dom.eff1, 
                       sig2.1 = 1, sig2.2 = 1, sig2.h = 1, eq.spacing = FALSE, 
                       cross.type = "f2", normalize = FALSE) {
-  Map <- sim.map(len = rep(100,3), n.mar = 101, eq.spacing = eq.spacing, 
+  Map <- qtl::sim.map(len = rep(100,3), n.mar = 101, eq.spacing = eq.spacing, 
                  include.x = FALSE)
-  Cross <- sim.cross(map = Map, n.ind = n.ind, type = cross.type)
-  mygeno <- pull.geno(Cross)
+  Cross <- qtl::sim.cross(map = Map, n.ind = n.ind, type = cross.type)
+  mygeno <- qtl::pull.geno(Cross)
   q <- mygeno[, "D1M80"]
-  h <- mu + rnorm(n.ind, 0, sqrt(sig2.h))
+  h <- mu + stats::rnorm(n.ind, 0, sqrt(sig2.h))
   if (cross.type == "bc") {
     add.q <- q - 1.5
-    y1 <- mu + add.q * add.eff1 + beta1h * h + rnorm(n.ind, 0, sqrt(sig2.1))
+    y1 <- mu + add.q * add.eff1 + beta1h * h + stats::rnorm(n.ind, 0, sqrt(sig2.1))
   }
   if (cross.type == "f2") {
     add.q <- q - 2
     dom.q <- (1 + add.q) * (1 - add.q) - 0.5
     y1 <- mu + add.q * add.eff1 + dom.q * dom.eff1 + beta1h * h + 
-          rnorm(n.ind, 0, sqrt(sig2.1))
+          stats::rnorm(n.ind, 0, sqrt(sig2.1))
   }
-  y2 <- mu + beta21 * y1 + beta2h * h + rnorm(n.ind, 0, sqrt(sig2.2))
+  y2 <- mu + beta21 * y1 + beta2h * h + stats::rnorm(n.ind, 0, sqrt(sig2.2))
   if (normalize) {
     y1 <- normal.trans(y1)
     y2 <- normal.trans(y2)
@@ -372,23 +372,23 @@ SimCross2 <- function(n.ind, mu, beta21, beta1h, beta2h, add.eff1, dom.eff1,
 SimCross3 <- function(n.ind, mu, beta21, add.eff1, dom.eff1, add.eff2,
                       dom.eff2, sig2.1 = 1, sig2.2 = 1, eq.spacing = FALSE, 
                       cross.type = "f2", normalize = FALSE) {
-  Map <- sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
+  Map <- qtl::sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
                  include.x = FALSE)
-  Cross <- sim.cross(map = Map, n.ind = n.ind, type = cross.type)
-  mygeno <- pull.geno(Cross)
+  Cross <- qtl::sim.cross(map = Map, n.ind = n.ind, type = cross.type)
+  mygeno <- qtl::pull.geno(Cross)
   q <- mygeno[, "D1M80"]
   if (cross.type == "bc") {
     add.q <- q - 1.5
-    y1 <- mu + add.q * add.eff1 + rnorm(n.ind, 0, sqrt(sig2.1))
-    y2 <- mu + add.q * add.eff2 + beta21 * y1 + rnorm(n.ind, 0, sqrt(sig2.2))
+    y1 <- mu + add.q * add.eff1 + stats::rnorm(n.ind, 0, sqrt(sig2.1))
+    y2 <- mu + add.q * add.eff2 + beta21 * y1 + stats::rnorm(n.ind, 0, sqrt(sig2.2))
   }
   if (cross.type == "f2") {
     add.q <- q - 2
     dom.q <- (1 + add.q) * (1 - add.q) - 0.5
     y1 <- mu + add.q * add.eff1 + dom.q * dom.eff1 + 
-          rnorm(n.ind, 0, sqrt(sig2.1))
+          stats::rnorm(n.ind, 0, sqrt(sig2.1))
     y2 <- mu + add.q * add.eff2 + dom.q * dom.eff2 + beta21 * y1 + 
-          rnorm(n.ind, 0, sqrt(sig2.2))
+          stats::rnorm(n.ind, 0, sqrt(sig2.2))
   }
   if (normalize) {
     y1 <- normal.trans(y1)
@@ -402,23 +402,23 @@ SimCross3 <- function(n.ind, mu, beta21, add.eff1, dom.eff1, add.eff2,
 SimCross4 <- function(n.ind, mu, add.eff1, dom.eff1, add.eff2, dom.eff2, 
                       sig2.1 = 1, sig2.2 = 1, eq.spacing = FALSE, 
                       cross.type = "f2", normalize = FALSE) {
-  Map <- sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
+  Map <- qtl::sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
                  include.x = FALSE)
-  Cross <- sim.cross(map = Map, n.ind = n.ind, type = cross.type)
-  mygeno <- pull.geno(Cross)
+  Cross <- qtl::sim.cross(map = Map, n.ind = n.ind, type = cross.type)
+  mygeno <- qtl::pull.geno(Cross)
   q <- mygeno[, "D1M80"]
   if (cross.type == "bc") {
     add.q <- q - 1.5
-    y1 <- mu + add.q * add.eff1 + rnorm(n.ind, 0, sqrt(sig2.1))
-    y2 <- mu + add.q * add.eff2 + rnorm(n.ind, 0, sqrt(sig2.2))
+    y1 <- mu + add.q * add.eff1 + stats::rnorm(n.ind, 0, sqrt(sig2.1))
+    y2 <- mu + add.q * add.eff2 + stats::rnorm(n.ind, 0, sqrt(sig2.2))
   }
   if (cross.type == "f2") {
     add.q <- q - 2
     dom.q <- (1 + add.q) * (1 - add.q) - 0.5
     y1 <- mu + add.q * add.eff1 + dom.q * dom.eff1 + 
-          rnorm(n.ind, 0, sqrt(sig2.1))
+          stats::rnorm(n.ind, 0, sqrt(sig2.1))
     y2 <- mu + add.q * add.eff2 + dom.q * dom.eff2 + 
-          rnorm(n.ind, 0, sqrt(sig2.2))
+          stats::rnorm(n.ind, 0, sqrt(sig2.2))
   }
   if (normalize) {
     y1 <- normal.trans(y1)
@@ -433,24 +433,24 @@ SimCross5 <- function(n.ind, mu, add.eff1, dom.eff1, add.eff2, dom.eff2,
                       beta1h, beta2h, sig2.1 = 1, sig2.2 = 1, sig2.h = 1, 
                       eq.spacing = FALSE, cross.type = "f2", 
                       normalize = FALSE) {
-  Map <- sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
+  Map <- qtl::sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
                  include.x = FALSE)
-  Cross <- sim.cross(map = Map, n.ind = n.ind, type = cross.type)
-  mygeno <- pull.geno(Cross)
+  Cross <- qtl::sim.cross(map = Map, n.ind = n.ind, type = cross.type)
+  mygeno <- qtl::pull.geno(Cross)
   q <- mygeno[, "D1M80"]
-  h <- mu + rnorm(n.ind, 0, sqrt(sig2.h))
+  h <- mu + stats::rnorm(n.ind, 0, sqrt(sig2.h))
   if (cross.type == "bc") {
     add.q <- q - 1.5
-    y1 <- mu + add.q * add.eff1 + h * beta1h + rnorm(n.ind, 0, sqrt(sig2.1))
-    y2 <- mu + add.q * add.eff2 + h * beta2h + rnorm(n.ind, 0, sqrt(sig2.2))
+    y1 <- mu + add.q * add.eff1 + h * beta1h + stats::rnorm(n.ind, 0, sqrt(sig2.1))
+    y2 <- mu + add.q * add.eff2 + h * beta2h + stats::rnorm(n.ind, 0, sqrt(sig2.2))
   }
   if (cross.type == "f2") {
     add.q <- q - 2
     dom.q <- (1 + add.q) * (1 - add.q) - 0.5
     y1 <- mu + add.q * add.eff1 + dom.q * dom.eff1 + h * beta1h + 
-          rnorm(n.ind, 0, sqrt(sig2.1))
+          stats::rnorm(n.ind, 0, sqrt(sig2.1))
     y2 <- mu + add.q * add.eff2 + dom.q * dom.eff2 + h * beta2h + 
-          rnorm(n.ind, 0, sqrt(sig2.2))
+          stats::rnorm(n.ind, 0, sqrt(sig2.2))
   }
   if (normalize) {
     y1 <- normal.trans(y1)
@@ -464,23 +464,23 @@ SimCross5 <- function(n.ind, mu, add.eff1, dom.eff1, add.eff2, dom.eff2,
 SimCross6 <- function(n.ind, mu, add.eff, dom.eff, beta1h, beta2h, 
                       sig2.1 = 1, sig2.2 = 1, sig2.h = 1, eq.spacing = FALSE, 
                       cross.type = "f2", normalize = FALSE) {
-  Map <- sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
+  Map <- qtl::sim.map(len = rep(100, 3), n.mar = 101, eq.spacing = eq.spacing, 
                  include.x = FALSE)
-  Cross <- sim.cross(map = Map, n.ind = n.ind, type = cross.type)
-  mygeno <- pull.geno(Cross)
+  Cross <- qtl::sim.cross(map = Map, n.ind = n.ind, type = cross.type)
+  mygeno <- qtl::pull.geno(Cross)
   q <- mygeno[, "D1M80"]
   if (cross.type == "bc") {
     add.q <- q - 1.5
-    h <- mu + add.q * add.eff + rnorm(n.ind, 0, sqrt(sig2.h))
+    h <- mu + add.q * add.eff + stats::rnorm(n.ind, 0, sqrt(sig2.h))
   }
   if (cross.type == "f2") {
     add.q <- q - 2
     dom.q <- (1 + add.q) * (1 - add.q) - 0.5
     h <- mu + add.q * add.eff + dom.q * dom.eff + 
-         rnorm(n.ind, 0, sqrt(sig2.h))
+         stats::rnorm(n.ind, 0, sqrt(sig2.h))
   }
-  y1 <- mu + h * beta1h + rnorm(n.ind, 0, sqrt(sig2.1))
-  y2 <- mu + h * beta2h + rnorm(n.ind, 0, sqrt(sig2.2))
+  y1 <- mu + h * beta1h + stats::rnorm(n.ind, 0, sqrt(sig2.1))
+  y2 <- mu + h * beta2h + stats::rnorm(n.ind, 0, sqrt(sig2.2))
   if (normalize) {
     y1 <- normal.trans(y1)
     y2 <- normal.trans(y2)
